@@ -17,9 +17,10 @@
   )
 
   sunburst(
-    jsondata = tm_nest,
+    data = tm_nest,
     valueField = "vSize",
     count = TRUE,
-    colors = htmlwidgets::JS("function(d){return d3.select(this).datum().color;}")
+    colors = htmlwidgets::JS("function(d){return d3.select(this).datum().data.color;}"),
+    withD3 = TRUE
   )
 }
